#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua51%{nil}
%define mod_name luasec
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif
Version:        1.3.1
Release:        1.5
Summary:        A Lua binding for OpenSSL
License:        MIT
URL:            https://github.com/brunoos/luasec
Source:         https://github.com/brunoos/%{mod_name}/archive/v%{version}/%{mod_name}-%{version}.tar.gz
BuildRequires:  %{flavor}-devel
BuildRequires:  %{flavor}-luasocket
BuildRequires:  libopenssl-devel
BuildRequires:  lua-macros
Requires:       %{flavor}
Requires:       %{flavor}-luasocket
%lua_provides

%description
It is a binding for OpenSSL library to provide TLS/SSL communication.
It takes an already established TCP connection and creates a secure
session between the peers.

%prep
%autosetup -n %{mod_name}-%{version}

%build
# regenerate OpenSSL options
cd src
lua options.lua -g /usr/include/openssl/ssl.h > options.c
cd ..
#
make %{?_make_output_sync} %{?_smp_mflags} linux \
  CFLAGS="%{optflags} -fPIC -I%{lua_incdir} -I. -DWITH_LUASOCKET -DLUASOCKET_DEBUG -DLUA_COMPAT_APIINTCASTS"

%install
%make_install LUAPATH=%{lua_noarchdir} LUACPATH=%{lua_archdir}

%files
%license LICENSE
%doc CHANGELOG README.md
%{lua_archdir}/ssl.so
%{lua_noarchdir}/ssl.lua
%{lua_noarchdir}/ssl/

%changelog
* Tue Jul 11 2023 Gordon Leung <pirateclip@protonmail.com>
- Update to version 1.3.1
  * Add support for tls-psk
  * See: https://github.com/brunoos/luasec/compare/v1.2.0...v1.3.1
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Opencode %%make_build to prevent build failure when not defined.
* Sat Aug 20 2022 Gordon Leung <pirateclip@protonmail.com>
- Update to version 1.2.0:
  * Support passing DANE flags
  * Add key material export method
  * backguard compat for openssl on providers, like LTS linuxes
* Sat Dec 18 2021 Callum Farmer <gmbr3@opensuse.org>
- regenerate OpenSSL options for build version
* Sat Dec 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.0.2:
  * Fix handle SSL_send SYSCALL error without errno
  * Fix off by one in cert:validat(notafter)
  * Fix meth_get_sinagure => meth_get_signature_name function name
  * Fix update the Lua state reference on the selected SSL context
    after SNI
  * Fix ignore SSL_OP_BIT(n) macro and update option.c
  * Fix: luaL_Buffer can use the stack and
    breakbuffer_meth_receive()
  * Add cert:getsignaturename()
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Sun Nov  3 2019 Matej Cepl <mcepl@suse.com>
- Update to luasec 0.9. Too many changes to enlist here,
  CHANGELOG file is included in the package.
- Patch lua-sec-0.6-openssl_110.patch has been removed as it is
  fully included upstream.
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Thu Jul 13 2017 tchvatal@suse.com
- Switch to multibuild slotted approach
- Add dep on lua-luasocket
* Tue Jul 11 2017 tchvatal@suse.com
- Version update to 0.6:
  * compat with lua5.2 and lua5.3
  * bunch of bugfixes
- Fix build with namespaced lua
- Respect optflags
* Sat Sep 17 2016 mailaender@opensuse.org
- update to version 0.5.1
- drop luasec-makefile.patch
* Mon Oct 20 2014 i@marguerite.su
- update version 0.5+git20140911
* Sun Feb 23 2014 i@marguerite.su
- update version 0.5.git20140223
- no longer %%optflags. -fstack-protector doesn't work.
* Fri Jun 28 2013 i@marguerite.su
- use lua51-devel for openSUSE 12.2+.
* Sat Feb 11 2012 toganm@opensuse.org
- Update to 0.4.1
  * SSL options updated --- based on OpenSSL 1.0.0d.
  * Activate SSL_MODE_RELEASE_BUFFERS by default if it is available.
  (thanks Prosody Project)
  * Enabled rpm %%optflags
  * added changes file
